==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/igr-polar-area-series.js <==
import { __extends } from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { IgrPolarLineSeriesBase } from "./igr-polar-line-series-base";
import { PolarAreaSeries } from "./PolarAreaSeries";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent polar area series.
*/
var IgrPolarAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrPolarAreaSeries, _super);
    function IgrPolarAreaSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrPolarAreaSeries.prototype.createImplementation = function () {
        return new PolarAreaSeries();
    };
    Object.defineProperty(IgrPolarAreaSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPolarAreaSeries.prototype, "isArea", {
        /**
         * Gets whether the current series shows an area shape.
        */
        get: function () {
            return this.i.d8;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPolarAreaSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.zn;
        },
        set: function (v) {
            this.i.zn = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrPolarAreaSeries;
}(IgrPolarLineSeriesBase));
export { IgrPolarAreaSeries };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/igr-polar-area-series.js <==
import { __extends } from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { IgrPolarLineSeriesBase } from "./igr-polar-line-series-base";
import { PolarAreaSeries } from "./PolarAreaSeries";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent polar area series.
*/
var IgrPolarAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrPolarAreaSeries, _super);
    function IgrPolarAreaSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrPolarAreaSeries.prototype.createImplementation = function () {
        return new PolarAreaSeries();
    };
    Object.defineProperty(IgrPolarAreaSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPolarAreaSeries.prototype, "isArea", {
        /**
         * Gets whether the current series shows an area shape.
        */
        get: function () {
            return this.i.et;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPolarAreaSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.acq;
        },
        set: function (v) {
            this.i.acq = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrPolarAreaSeries;
}(IgrPolarLineSeriesBase));
export { IgrPolarAreaSeries };
